==> scalar__import-0.4.6.jar: META-INF/resources/webjars/scalar__import/0.4.6/CHANGELOG.md <==
# @scalar/import

## 0.4.6

### Patch Changes

- Updated dependencies [ee3eb77]
- Updated dependencies [7ca47ab]
  - @scalar/openapi-parser@0.14.0
  - @scalar/oas-utils@0.4.2

## 0.4.5

### Patch Changes

- @scalar/oas-utils@0.4.1

## 0.4.4

### Patch Changes

- Updated dependencies [1e87feb]
- Updated dependencies [1e87feb]
- Updated dependencies [cad6277]
  - @scalar/openapi-parser@0.13.0
  - @scalar/oas-utils@0.4.0

## 0.4.3

### Patch Changes

- Updated dependencies [151ef09]
- Updated dependencies [442c0a3]
- Updated dependencies [edf694b]
  - @scalar/oas-utils@0.3.2
  - @scalar/openapi-parser@0.12.0

## 0.4.2

### Patch Changes

- Updated dependencies [ea20eb4]
  - @scalar/openapi-parser@0.11.1
  - @scalar/oas-utils@0.3.1

## 0.4.1

### Patch Changes

- Updated dependencies [4440949]
  - @scalar/oas-utils@0.3.1
  - @scalar/openapi-parser@0.11.0

## 0.4.0

### Minor Changes

- 483ca93: chore: require Node 20 (or above)

### Patch Changes

- Updated dependencies [bd602d3]
- Updated dependencies [30bab1d]
- Updated dependencies [483ca93]
- Updated dependencies [1d1470c]
  - @scalar/openapi-parser@0.11.0
  - @scalar/oas-utils@0.3.0

## 0.3.27

### Patch Changes

- @scalar/oas-utils@0.2.144
- @scalar/openapi-parser@0.10.17

## 0.3.26

### Patch Changes

- Updated dependencies [67aa0f4]
  - @scalar/oas-utils@0.2.143
  - @scalar/openapi-parser@0.10.17

## 0.3.25

### Patch Changes

- Updated dependencies [cd6cf24]
  - @scalar/oas-utils@0.2.142

## 0.3.24

### Patch Changes

- 8c7bad8: chore: move build tooling to esbuild
- Updated dependencies [8c7bad8]
  - @scalar/openapi-parser@0.10.17
  - @scalar/oas-utils@0.2.141

## 0.3.23

### Patch Changes

- Updated dependencies [e8457cb]
  - @scalar/oas-utils@0.2.140
  - @scalar/openapi-parser@0.10.16

## 0.3.22

### Patch Changes

- Updated dependencies [d2f27f4]
  - @scalar/oas-utils@0.2.139

## 0.3.21

### Patch Changes

- Updated dependencies [5d24800]
  - @scalar/oas-utils@0.2.138

## 0.3.20

### Patch Changes

- @scalar/oas-utils@0.2.137
- @scalar/openapi-parser@0.10.16

## 0.3.19

### Patch Changes

- Updated dependencies [eb4854d]
  - @scalar/oas-utils@0.2.136
  - @scalar/openapi-parser@0.10.16

## 0.3.18

### Patch Changes

- Updated dependencies [fa8ed84]
- Updated dependencies [fa8ed84]
- Updated dependencies [8d54857]
  - @scalar/oas-utils@0.2.135
  - @scalar/openapi-parser@0.10.16

## 0.3.17

### Patch Changes

- @scalar/oas-utils@0.2.134
- @scalar/openapi-parser@0.10.16

## 0.3.16

### Patch Changes

- Updated dependencies [e489824]
  - @scalar/oas-utils@0.2.133

## 0.3.15

### Patch Changes

- Updated dependencies [c5047ee]
  - @scalar/openapi-parser@0.10.16
  - @scalar/oas-utils@0.2.132

## 0.3.14

### Patch Changes

- Updated dependencies [4abe4f8]
- Updated dependencies [4abe4f8]
  - @scalar/openapi-parser@0.10.15
  - @scalar/oas-utils@0.2.131

## 0.3.13

### Patch Changes

- @scalar/oas-utils@0.2.130
- @scalar/openapi-parser@0.10.14

## 0.3.12

### Patch Changes

- @scalar/oas-utils@0.2.129

## 0.3.11

### Patch Changes

- Updated dependencies [18b1be9]
  - @scalar/oas-utils@0.2.128

## 0.3.10

### Patch Changes

- Updated dependencies [bf961b1]
- Updated dependencies [a176b7e]
  - @scalar/oas-utils@0.2.127

## 0.3.9

### Patch Changes

- Updated dependencies [a571d36]
- Updated dependencies [cf5bf65]
  - @scalar/oas-utils@0.2.126
  - @scalar/openapi-parser@0.10.14

## 0.3.8

### Patch Changes

- Updated dependencies [d5a687f]
- Updated dependencies [e62e677]
- Updated dependencies [04e27a1]
- Updated dependencies [846d015]
  - @scalar/openapi-parser@0.10.13
  - @scalar/oas-utils@0.2.125

## 0.3.7

### Patch Changes

- Updated dependencies [0de80ae]
  - @scalar/oas-utils@0.2.124

## 0.3.6

### Patch Changes

- Updated dependencies [52f6f4c]
  - @scalar/oas-utils@0.2.123
  - @scalar/openapi-parser@0.10.12

## 0.3.5

### Patch Changes

- @scalar/oas-utils@0.2.122
- @scalar/openapi-parser@0.10.12

## 0.3.4

### Patch Changes

- Updated dependencies [cbc1d08]
  - @scalar/openapi-parser@0.10.12
  - @scalar/oas-utils@0.2.121

## 0.3.3

### Patch Changes

- Updated dependencies [0f13162]
- Updated dependencies [0212daa]
  - @scalar/openapi-parser@0.10.11
  - @scalar/oas-utils@0.2.121

## 0.3.2

### Patch Changes

- Updated dependencies [cd75eeb]
  - @scalar/oas-utils@0.2.120
  - @scalar/openapi-parser@0.10.10

## 0.3.1

### Patch Changes

- @scalar/oas-utils@0.2.119

## 0.3.0

### Minor Changes

- 5f9a8a2: feat!: remove the spec prefix, make content and url top-level attributes

### Patch Changes

- 14c5d22: fix: getting configuration for galaxy example
  - @scalar/oas-utils@0.2.118
  - @scalar/openapi-parser@0.10.10

## 0.2.37

### Patch Changes

- @scalar/oas-utils@0.2.117
- @scalar/openapi-parser@0.10.10

## 0.2.36

### Patch Changes

- Updated dependencies [ab98841]
- Updated dependencies [db9ebbc]
  - @scalar/oas-utils@0.2.116

## 0.2.35

### Patch Changes

- Updated dependencies [0d8a24f]
  - @scalar/openapi-parser@0.10.10
  - @scalar/oas-utils@0.2.115

## 0.2.34

### Patch Changes

- Updated dependencies [fb22645]
  - @scalar/oas-utils@0.2.114

## 0.2.33

### Patch Changes

- Updated dependencies [a31973c]
  - @scalar/oas-utils@0.2.113
  - @scalar/openapi-parser@0.10.9

## 0.2.32

### Patch Changes

- @scalar/oas-utils@0.2.112
- @scalar/openapi-parser@0.10.9

## 0.2.31

### Patch Changes

- Updated dependencies [89d8b75]
- Updated dependencies [8a04b8d]
- Updated dependencies [1459ce7]
- Updated dependencies [8a04b8d]
  - @scalar/oas-utils@0.2.111
  - @scalar/openapi-parser@0.10.9

## 0.2.30

### Patch Changes

- @scalar/oas-utils@0.2.110

## 0.2.29

### Patch Changes

- Updated dependencies [4db5161]
  - @scalar/oas-utils@0.2.109
  - @scalar/openapi-parser@0.10.9

## 0.2.28

### Patch Changes

- Updated dependencies [9fc97da]
- Updated dependencies [12088f1]
- Updated dependencies [c10bbf5]
  - @scalar/oas-utils@0.2.108
  - @scalar/openapi-parser@0.10.9

## 0.2.27

### Patch Changes

- Updated dependencies [e350f23]
- Updated dependencies [738d21c]
  - @scalar/openapi-parser@0.10.8
  - @scalar/oas-utils@0.2.107

## 0.2.26

### Patch Changes

- Updated dependencies [ed92564]
  - @scalar/oas-utils@0.2.106

## 0.2.25

### Patch Changes

- 54fdfcb: chore: remove spec wording
- fa6afe8: chore: code formatting
- 4d30a35: fix: can’t parse HTML attributes with HTML tags inside
- Updated dependencies [54fdfcb]
- Updated dependencies [1223c1f]
  - @scalar/oas-utils@0.2.105
  - @scalar/openapi-parser@0.10.7

## 0.2.24

### Patch Changes

- Updated dependencies [4de3124]
- Updated dependencies [f500435]
- Updated dependencies [da5cf08]
- Updated dependencies [b5727ef]
- Updated dependencies [4de3124]
- Updated dependencies [34e6f52]
  - @scalar/openapi-parser@0.10.6
  - @scalar/oas-utils@0.2.104

## 0.2.23

### Patch Changes

- Updated dependencies [0f5df68]
- Updated dependencies [a30e7cc]
- Updated dependencies [937f791]
  - @scalar/oas-utils@0.2.103
  - @scalar/openapi-parser@0.10.5

## 0.2.22

### Patch Changes

- Updated dependencies [a34f834]
- Updated dependencies [ef98b9c]
- Updated dependencies [a34f834]
- Updated dependencies [ebdf762]
  - @scalar/oas-utils@0.2.102
  - @scalar/openapi-parser@0.10.4

## 0.2.21

### Patch Changes

- Updated dependencies [be34e7d]
  - @scalar/oas-utils@0.2.101
  - @scalar/openapi-parser@0.10.4

## 0.2.20

### Patch Changes

- Updated dependencies [12e7232]
- Updated dependencies [901970f]
- Updated dependencies [f1f39b0]
  - @scalar/oas-utils@0.2.100
  - @scalar/openapi-parser@0.10.4

## 0.2.19

### Patch Changes

- Updated dependencies [c803e2d]
  - @scalar/oas-utils@0.2.99

## 0.2.18

### Patch Changes

- @scalar/oas-utils@0.2.98
- @scalar/openapi-parser@0.10.4

## 0.2.17

### Patch Changes

- Updated dependencies [7df4472]
- Updated dependencies [64df4fc]
  - @scalar/oas-utils@0.2.97
  - @scalar/openapi-parser@0.10.4

## 0.2.16

### Patch Changes

- Updated dependencies [cf0e7b1]
- Updated dependencies [8dce84f]
  - @scalar/oas-utils@0.2.96
  - @scalar/openapi-parser@0.10.3

## 0.2.15

### Patch Changes

- Updated dependencies [3156ecd]
  - @scalar/oas-utils@0.2.95

## 0.2.14

### Patch Changes

- Updated dependencies [a36fada]
  - @scalar/oas-utils@0.2.94

## 0.2.13

### Patch Changes

- Updated dependencies [ca2d98b]
  - @scalar/oas-utils@0.2.93

## 0.2.12

### Patch Changes

- Updated dependencies [02b4201]
  - @scalar/oas-utils@0.2.92

## 0.2.11

### Patch Changes

- Updated dependencies [3791738]
  - @scalar/openapi-parser@0.10.2
  - @scalar/oas-utils@0.2.91

## 0.2.10

### Patch Changes

- @scalar/oas-utils@0.2.91

## 0.2.9

### Patch Changes

- Updated dependencies [573d113]
- Updated dependencies [c263aaf]
  - @scalar/oas-utils@0.2.90
  - @scalar/openapi-parser@0.10.1

## 0.2.8

### Patch Changes

- @scalar/oas-utils@0.2.89

## 0.2.7

### Patch Changes

- Updated dependencies [fbef0c3]
- Updated dependencies [fbef0c3]
  - @scalar/openapi-parser@0.10.0
  - @scalar/oas-utils@0.2.88

## 0.2.6

### Patch Changes

- Updated dependencies [8017ff9]
  - @scalar/oas-utils@0.2.87

## 0.2.5

### Patch Changes

- Updated dependencies [6fef2f3]
  - @scalar/openapi-parser@0.9.0
  - @scalar/oas-utils@0.2.86

## 0.2.4

### Patch Changes

- Updated dependencies [3eb0d11]
- Updated dependencies [b66a85c]
  - @scalar/oas-utils@0.2.86

## 0.2.3

### Patch Changes

- Updated dependencies [3b4a788]
- Updated dependencies [4c5be96]
- Updated dependencies [4c5be96]
  - @scalar/oas-utils@0.2.85

## 0.2.2

### Patch Changes

- Updated dependencies [9b4f85d]
  - @scalar/oas-utils@0.2.84

## 0.2.1

### Patch Changes

- Updated dependencies [f524411]
- Updated dependencies [10c9016]
- Updated dependencies [b11294c]
  - @scalar/oas-utils@0.2.83

## 0.2.0

### Minor Changes

- 6389557: feat: use X-Forwarded-Host header (if available)

### Patch Changes

- Updated dependencies [6389557]
  - @scalar/oas-utils@0.2.82

## 0.1.2

### Patch Changes

- Updated dependencies [98e9cb2]
  - @scalar/openapi-parser@0.8.10

## 0.1.1

### Patch Changes

- 82f7c35: fix: rollback proxy

## 0.1.0

### Minor Changes

- c98a99c: feat: use X-Forwarded-Host header (if available)

### Patch Changes

- Updated dependencies [4bcaa75]
- Updated dependencies [9eb6650]
- Updated dependencies [c98a99c]
  - @scalar/oas-utils@0.2.72

## 0.0.6

### Patch Changes

- a40999d: chore: added type safety rule noUncheckedIndexedAccess
  - @scalar/openapi-parser@0.8.9

## 0.0.5

### Patch Changes

- 779cf35: feat: import from escaped JS object
- Updated dependencies [757fade]
- Updated dependencies [a607115]
  - @scalar/openapi-parser@0.8.9

## 0.0.4

### Patch Changes

- 2275977: feat: import from way more sources, leverage the proxy more
- f2361b3: fix: resolve JSON/YAML URLs

## 0.0.3

### Patch Changes

- Updated dependencies [7323370]
  - @scalar/openapi-parser@0.8.8

## 0.0.2

### Patch Changes

- 05f20e4: fix: sandbox links with uppercase letters can not be resolved

## 0.0.1

### Patch Changes

- e930134: feat: new @scalar/import package :)

==> scalar__import-0.4.8.jar: META-INF/resources/webjars/scalar__import/0.4.8/CHANGELOG.md <==
# @scalar/import

## 0.4.8

### Patch Changes

- Updated dependencies [8bc9f20]
  - @scalar/helpers@0.0.3

## 0.4.7

### Patch Changes

- 8165b3b: feat(helpers): added new helpers package
- Updated dependencies [17bc0d8]
- Updated dependencies [b9dacba]
- Updated dependencies [a73e9be]
- Updated dependencies [8165b3b]
- Updated dependencies [49c04cf]
- Updated dependencies [f4332eb]
  - @scalar/openapi-parser@0.15.0
  - @scalar/helpers@0.0.2

## 0.4.6

### Patch Changes

- Updated dependencies [ee3eb77]
- Updated dependencies [7ca47ab]
  - @scalar/openapi-parser@0.14.0
  - @scalar/oas-utils@0.4.2

## 0.4.5

### Patch Changes

- @scalar/oas-utils@0.4.1

## 0.4.4

### Patch Changes

- Updated dependencies [1e87feb]
- Updated dependencies [1e87feb]
- Updated dependencies [cad6277]
  - @scalar/openapi-parser@0.13.0
  - @scalar/oas-utils@0.4.0

## 0.4.3

### Patch Changes

- Updated dependencies [151ef09]
- Updated dependencies [442c0a3]
- Updated dependencies [edf694b]
  - @scalar/oas-utils@0.3.2
  - @scalar/openapi-parser@0.12.0

## 0.4.2

### Patch Changes

- Updated dependencies [ea20eb4]
  - @scalar/openapi-parser@0.11.1
  - @scalar/oas-utils@0.3.1

## 0.4.1

### Patch Changes

- Updated dependencies [4440949]
  - @scalar/oas-utils@0.3.1
  - @scalar/openapi-parser@0.11.0

## 0.4.0

### Minor Changes

- 483ca93: chore: require Node 20 (or above)

### Patch Changes

- Updated dependencies [bd602d3]
- Updated dependencies [30bab1d]
- Updated dependencies [483ca93]
- Updated dependencies [1d1470c]
  - @scalar/openapi-parser@0.11.0
  - @scalar/oas-utils@0.3.0

## 0.3.27

### Patch Changes

- @scalar/oas-utils@0.2.144
- @scalar/openapi-parser@0.10.17

## 0.3.26

### Patch Changes

- Updated dependencies [67aa0f4]
  - @scalar/oas-utils@0.2.143
  - @scalar/openapi-parser@0.10.17

## 0.3.25

### Patch Changes

- Updated dependencies [cd6cf24]
  - @scalar/oas-utils@0.2.142

## 0.3.24

### Patch Changes

- 8c7bad8: chore: move build tooling to esbuild
- Updated dependencies [8c7bad8]
  - @scalar/openapi-parser@0.10.17
  - @scalar/oas-utils@0.2.141

## 0.3.23

### Patch Changes

- Updated dependencies [e8457cb]
  - @scalar/oas-utils@0.2.140
  - @scalar/openapi-parser@0.10.16

## 0.3.22

### Patch Changes

- Updated dependencies [d2f27f4]
  - @scalar/oas-utils@0.2.139

## 0.3.21

### Patch Changes

- Updated dependencies [5d24800]
  - @scalar/oas-utils@0.2.138

## 0.3.20

### Patch Changes

- @scalar/oas-utils@0.2.137
- @scalar/openapi-parser@0.10.16

## 0.3.19

### Patch Changes

- Updated dependencies [eb4854d]
  - @scalar/oas-utils@0.2.136
  - @scalar/openapi-parser@0.10.16

## 0.3.18

### Patch Changes

- Updated dependencies [fa8ed84]
- Updated dependencies [fa8ed84]
- Updated dependencies [8d54857]
  - @scalar/oas-utils@0.2.135
  - @scalar/openapi-parser@0.10.16

## 0.3.17

### Patch Changes

- @scalar/oas-utils@0.2.134
- @scalar/openapi-parser@0.10.16

## 0.3.16

### Patch Changes

- Updated dependencies [e489824]
  - @scalar/oas-utils@0.2.133

## 0.3.15

### Patch Changes

- Updated dependencies [c5047ee]
  - @scalar/openapi-parser@0.10.16
  - @scalar/oas-utils@0.2.132

## 0.3.14

### Patch Changes

- Updated dependencies [4abe4f8]
- Updated dependencies [4abe4f8]
  - @scalar/openapi-parser@0.10.15
  - @scalar/oas-utils@0.2.131

## 0.3.13

### Patch Changes

- @scalar/oas-utils@0.2.130
- @scalar/openapi-parser@0.10.14

## 0.3.12

### Patch Changes

- @scalar/oas-utils@0.2.129

## 0.3.11

### Patch Changes

- Updated dependencies [18b1be9]
  - @scalar/oas-utils@0.2.128

## 0.3.10

### Patch Changes

- Updated dependencies [bf961b1]
- Updated dependencies [a176b7e]
  - @scalar/oas-utils@0.2.127

## 0.3.9

### Patch Changes

- Updated dependencies [a571d36]
- Updated dependencies [cf5bf65]
  - @scalar/oas-utils@0.2.126
  - @scalar/openapi-parser@0.10.14

## 0.3.8

### Patch Changes

- Updated dependencies [d5a687f]
- Updated dependencies [e62e677]
- Updated dependencies [04e27a1]
- Updated dependencies [846d015]
  - @scalar/openapi-parser@0.10.13
  - @scalar/oas-utils@0.2.125

## 0.3.7

### Patch Changes

- Updated dependencies [0de80ae]
  - @scalar/oas-utils@0.2.124

## 0.3.6

### Patch Changes

- Updated dependencies [52f6f4c]
  - @scalar/oas-utils@0.2.123
  - @scalar/openapi-parser@0.10.12

## 0.3.5

### Patch Changes

- @scalar/oas-utils@0.2.122
- @scalar/openapi-parser@0.10.12

## 0.3.4

### Patch Changes

- Updated dependencies [cbc1d08]
  - @scalar/openapi-parser@0.10.12
  - @scalar/oas-utils@0.2.121

## 0.3.3

### Patch Changes

- Updated dependencies [0f13162]
- Updated dependencies [0212daa]
  - @scalar/openapi-parser@0.10.11
  - @scalar/oas-utils@0.2.121

## 0.3.2

### Patch Changes

- Updated dependencies [cd75eeb]
  - @scalar/oas-utils@0.2.120
  - @scalar/openapi-parser@0.10.10

## 0.3.1

### Patch Changes

- @scalar/oas-utils@0.2.119

## 0.3.0

### Minor Changes

- 5f9a8a2: feat!: remove the spec prefix, make content and url top-level attributes

### Patch Changes

- 14c5d22: fix: getting configuration for galaxy example
  - @scalar/oas-utils@0.2.118
  - @scalar/openapi-parser@0.10.10

## 0.2.37

### Patch Changes

- @scalar/oas-utils@0.2.117
- @scalar/openapi-parser@0.10.10

## 0.2.36

### Patch Changes

- Updated dependencies [ab98841]
- Updated dependencies [db9ebbc]
  - @scalar/oas-utils@0.2.116

## 0.2.35

### Patch Changes

- Updated dependencies [0d8a24f]
  - @scalar/openapi-parser@0.10.10
  - @scalar/oas-utils@0.2.115

## 0.2.34

### Patch Changes

- Updated dependencies [fb22645]
  - @scalar/oas-utils@0.2.114

## 0.2.33

### Patch Changes

- Updated dependencies [a31973c]
  - @scalar/oas-utils@0.2.113
  - @scalar/openapi-parser@0.10.9

## 0.2.32

### Patch Changes

- @scalar/oas-utils@0.2.112
- @scalar/openapi-parser@0.10.9

## 0.2.31

### Patch Changes

- Updated dependencies [89d8b75]
- Updated dependencies [8a04b8d]
- Updated dependencies [1459ce7]
- Updated dependencies [8a04b8d]
  - @scalar/oas-utils@0.2.111
  - @scalar/openapi-parser@0.10.9

## 0.2.30

### Patch Changes

- @scalar/oas-utils@0.2.110

## 0.2.29

### Patch Changes

- Updated dependencies [4db5161]
  - @scalar/oas-utils@0.2.109
  - @scalar/openapi-parser@0.10.9

## 0.2.28

### Patch Changes

- Updated dependencies [9fc97da]
- Updated dependencies [12088f1]
- Updated dependencies [c10bbf5]
  - @scalar/oas-utils@0.2.108
  - @scalar/openapi-parser@0.10.9

## 0.2.27

### Patch Changes

- Updated dependencies [e350f23]
- Updated dependencies [738d21c]
  - @scalar/openapi-parser@0.10.8
  - @scalar/oas-utils@0.2.107

## 0.2.26

### Patch Changes

- Updated dependencies [ed92564]
  - @scalar/oas-utils@0.2.106

## 0.2.25

### Patch Changes

- 54fdfcb: chore: remove spec wording
- fa6afe8: chore: code formatting
- 4d30a35: fix: can’t parse HTML attributes with HTML tags inside
- Updated dependencies [54fdfcb]
- Updated dependencies [1223c1f]
  - @scalar/oas-utils@0.2.105
  - @scalar/openapi-parser@0.10.7

## 0.2.24

### Patch Changes

- Updated dependencies [4de3124]
- Updated dependencies [f500435]
- Updated dependencies [da5cf08]
- Updated dependencies [b5727ef]
- Updated dependencies [4de3124]
- Updated dependencies [34e6f52]
  - @scalar/openapi-parser@0.10.6
  - @scalar/oas-utils@0.2.104

## 0.2.23

### Patch Changes

- Updated dependencies [0f5df68]
- Updated dependencies [a30e7cc]
- Updated dependencies [937f791]
  - @scalar/oas-utils@0.2.103
  - @scalar/openapi-parser@0.10.5

## 0.2.22

### Patch Changes

- Updated dependencies [a34f834]
- Updated dependencies [ef98b9c]
- Updated dependencies [a34f834]
- Updated dependencies [ebdf762]
  - @scalar/oas-utils@0.2.102
  - @scalar/openapi-parser@0.10.4

## 0.2.21

### Patch Changes

- Updated dependencies [be34e7d]
  - @scalar/oas-utils@0.2.101
  - @scalar/openapi-parser@0.10.4

## 0.2.20

### Patch Changes

- Updated dependencies [12e7232]
- Updated dependencies [901970f]
- Updated dependencies [f1f39b0]
  - @scalar/oas-utils@0.2.100
  - @scalar/openapi-parser@0.10.4

## 0.2.19

### Patch Changes

- Updated dependencies [c803e2d]
  - @scalar/oas-utils@0.2.99

## 0.2.18

### Patch Changes

- @scalar/oas-utils@0.2.98
- @scalar/openapi-parser@0.10.4

## 0.2.17

### Patch Changes

- Updated dependencies [7df4472]
- Updated dependencies [64df4fc]
  - @scalar/oas-utils@0.2.97
  - @scalar/openapi-parser@0.10.4

## 0.2.16

### Patch Changes

- Updated dependencies [cf0e7b1]
- Updated dependencies [8dce84f]
  - @scalar/oas-utils@0.2.96
  - @scalar/openapi-parser@0.10.3

## 0.2.15

### Patch Changes

- Updated dependencies [3156ecd]
  - @scalar/oas-utils@0.2.95

## 0.2.14

### Patch Changes

- Updated dependencies [a36fada]
  - @scalar/oas-utils@0.2.94

## 0.2.13

### Patch Changes

- Updated dependencies [ca2d98b]
  - @scalar/oas-utils@0.2.93

## 0.2.12

### Patch Changes

- Updated dependencies [02b4201]
  - @scalar/oas-utils@0.2.92

## 0.2.11

### Patch Changes

- Updated dependencies [3791738]
  - @scalar/openapi-parser@0.10.2
  - @scalar/oas-utils@0.2.91

## 0.2.10

### Patch Changes

- @scalar/oas-utils@0.2.91

## 0.2.9

### Patch Changes

- Updated dependencies [573d113]
- Updated dependencies [c263aaf]
  - @scalar/oas-utils@0.2.90
  - @scalar/openapi-parser@0.10.1

## 0.2.8

### Patch Changes

- @scalar/oas-utils@0.2.89

## 0.2.7

### Patch Changes

- Updated dependencies [fbef0c3]
- Updated dependencies [fbef0c3]
  - @scalar/openapi-parser@0.10.0
  - @scalar/oas-utils@0.2.88

## 0.2.6

### Patch Changes

- Updated dependencies [8017ff9]
  - @scalar/oas-utils@0.2.87

## 0.2.5

### Patch Changes

- Updated dependencies [6fef2f3]
  - @scalar/openapi-parser@0.9.0
  - @scalar/oas-utils@0.2.86

## 0.2.4

### Patch Changes

- Updated dependencies [3eb0d11]
- Updated dependencies [b66a85c]
  - @scalar/oas-utils@0.2.86

## 0.2.3

### Patch Changes

- Updated dependencies [3b4a788]
- Updated dependencies [4c5be96]
- Updated dependencies [4c5be96]
  - @scalar/oas-utils@0.2.85

## 0.2.2

### Patch Changes

- Updated dependencies [9b4f85d]
  - @scalar/oas-utils@0.2.84

## 0.2.1

### Patch Changes

- Updated dependencies [f524411]
- Updated dependencies [10c9016]
- Updated dependencies [b11294c]
  - @scalar/oas-utils@0.2.83

## 0.2.0

### Minor Changes

- 6389557: feat: use X-Forwarded-Host header (if available)

### Patch Changes

- Updated dependencies [6389557]
  - @scalar/oas-utils@0.2.82

## 0.1.2

### Patch Changes

- Updated dependencies [98e9cb2]
  - @scalar/openapi-parser@0.8.10

## 0.1.1

### Patch Changes

- 82f7c35: fix: rollback proxy

## 0.1.0

### Minor Changes

- c98a99c: feat: use X-Forwarded-Host header (if available)

### Patch Changes

- Updated dependencies [4bcaa75]
- Updated dependencies [9eb6650]
- Updated dependencies [c98a99c]
  - @scalar/oas-utils@0.2.72

## 0.0.6

### Patch Changes

- a40999d: chore: added type safety rule noUncheckedIndexedAccess
  - @scalar/openapi-parser@0.8.9

## 0.0.5

### Patch Changes

- 779cf35: feat: import from escaped JS object
- Updated dependencies [757fade]
- Updated dependencies [a607115]
  - @scalar/openapi-parser@0.8.9

## 0.0.4

### Patch Changes

- 2275977: feat: import from way more sources, leverage the proxy more
- f2361b3: fix: resolve JSON/YAML URLs

## 0.0.3

### Patch Changes

- Updated dependencies [7323370]
  - @scalar/openapi-parser@0.8.8

## 0.0.2

### Patch Changes

- 05f20e4: fix: sandbox links with uppercase letters can not be resolved

## 0.0.1

### Patch Changes

- e930134: feat: new @scalar/import package :)
